@@ -18,11 +18,8 @@ deleteFiles.redcapApiConnection <- function(rcon,
                                             field           = NULL, 
                                             event           = NULL, 
                                             repeat_instance = NULL,
-                                            ..., 
-                                            error_handling  = getOption("redcap_error_handling"),
-                                            config          = list(), 
-                                            api_param       = list()){
-  
+                                            ...)
+{
   if (is.numeric(record)) record <- as.character(record)
   
   ###########################################################################
@@ -55,20 +52,7 @@ deleteFiles.redcapApiConnection <- function(rcon,
                                any.missing = FALSE, 
                                null.ok = TRUE,
                                add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"), 
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   # make sure 'field' exist in the project and are 'file' fields
@@ -113,25 +97,9 @@ deleteFiles.redcapApiConnection <- function(rcon,
                returnFormat = 'csv', 
                event = event, 
                repeat_instance = repeat_instance)
-  
-  body <- body[lengths(body) > 0]
-  
-  #* Delete the file
-  #* The tryCatch here seems a little quirky.  My best understanding is that since the API is not returning
-  #* anything into the 'content' attribute returned by POST, POST is casting an error.  Oddly, an error in this
-  #* case, an error means the action was successfully performed.  The tryCatch call negotiates that oddity to
-  #* get the desired result.
-  
+
   ###########################################################################
   # Make the API Call
-  
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-  
-  if (response$status_code != "200")
-    redcapError(response, error_handling)
-  else 
-    invisible(TRUE)
-  
+  makeApiCall(rcon, body, ...)
+  invisible(TRUE)
 }
