@@ -22,30 +22,6 @@ test_that(
   }
 )
 
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    expect_error(exportArms(rcon, 
-                            error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(exportArms(rcon, 
-                            config = list(1)), 
-                 "'config': Must have names")
-    expect_error(exportArms(rcon, 
-                            config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(exportArms(rcon, 
-                            api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(exportArms(rcon, 
-                            api_param = "not a list"), 
-                 "'api_param': Must be of type 'list'")
-  }
-)
-
 #####################################################################
 # Import Arms Validation
 
@@ -108,14 +84,10 @@ test_that(
 )
 
 test_that(
-  "Return an error when error handling isn't one of null, error", 
+  "Validations of config and api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(importArms(rcon, 
-                            data = Arms,
-                            error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+
     expect_error(importArms(rcon,
                             data = Arms,
                             config = list(1)),
@@ -159,33 +131,3 @@ test_that(
                  "'arms': Must be of type 'character'")
   }
 )
-
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    
-    expect_error(deleteArms(rcon,
-                            arms = 1,
-                            error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(deleteArms(rcon,
-                            arms = 1,
-                            config = list(1)), 
-                 "'config': Must have names")
-    expect_error(deleteArms(rcon,
-                            arms = 1,
-                            config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(deleteArms(rcon, 
-                            arms = 1,
-                            api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(deleteArms(rcon, 
-                            arms = 1,
-                            api_param = "not a list"), 
-                 "'api_param': Must be of type 'list'")
-  }
-)
