@@ -81,16 +81,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(exportFromFileRepository(rcon, 
-                                          doc_id = 123,
-                                          dir = tempdir(), 
-                                          dir_create = FALSE, 
-                                          error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+
     expect_error(exportFromFileRepository(rcon, 
                                           doc_id = 123,
                                           dir = tempdir(), 
@@ -175,41 +169,6 @@ test_that(
   }
 )
 
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    expect_error(importToFileRepository(rcon, 
-                                        file = "somefile.pdf",
-                                        folder_id = 10,  
-                                        error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(importToFileRepository(rcon,  
-                                        file = "somefile.pdf",
-                                        folder_id = 10, 
-                                        config = list(1)), 
-                 "'config': Must have names")
-    expect_error(importToFileRepository(rcon,  
-                                        file = "somefile.pdf",
-                                        folder_id = 10, 
-                                        config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(importToFileRepository(rcon,  
-                                        file = "somefile.pdf",
-                                        folder_id = 10, 
-                                        api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(importToFileRepository(rcon,  
-                                        file = "somefile.pdf",
-                                        folder_id = 10, 
-                                        api_param = "not a list"), 
-                 "'api_param': Must be of type 'list'")
-  }
-)
-
-
 #####################################################################
 # deleteFromFileRepository
 
@@ -235,34 +194,3 @@ test_that(
                  "'doc_id'[:] Must be of type 'integerish'")
   }
 )
-
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    expect_error(deleteFromFileRepository(rcon, 
-                                          doc_id = 10,
-                                          error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(deleteFromFileRepository(rcon,   
-                                          doc_id = 10, 
-                                          config = list(1)), 
-                 "'config': Must have names")
-    expect_error(deleteFromFileRepository(rcon,   
-                                          doc_id = 10, 
-                                          config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(deleteFromFileRepository(rcon,   
-                                          doc_id = 10, 
-                                          api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(deleteFromFileRepository(rcon,   
-                                          doc_id = 10, 
-                                          api_param = "not a list"), 
-                 "'api_param': Must be of type 'list'")
-  }
-)
-
-
