@@ -42,13 +42,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(preserveProject(rcon, 
-                                 error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+   
     expect_error(preserveProject(rcon, 
                                  config = list(1)), 
                  "'config': Must have names")
@@ -135,17 +132,16 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(purgeProject(rcon, 
-                              error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(purgeProject(rcon, 
+
+    expect_error(purgeProject(rcon,
+                              arms=TRUE,
                               config = list(1)), 
                  "'config': Must have names")
-    expect_error(purgeProject(rcon, 
+    expect_error(purgeProject(rcon,
+                              arms=TRUE,
                               config = "not a list"), 
                  "'config': Must be of type 'list'")
   }
@@ -218,21 +214,3 @@ test_that(
                  "'flush': Must have length 1") 
   }
 )
-
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    expect_error(restoreProject(rcon, 
-                                error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(restoreProject(rcon, 
-                                config = list(1)), 
-                 "'config': Must have names")
-    expect_error(restoreProject(rcon, 
-                                config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-  }
-)
